@@ -53,7 +53,7 @@ sub handle_response {
 
     # verify the signing certificate
     my $cert = $x->signer_cert;
-    my $ca = Crypt::OpenSSL::VerifyX509->new($self->cacert);
+    my $ca = Crypt::OpenSSL::Verify->new($self->cacert, { strict_certs => 0, });
     $ret = $ca->verify($cert);
     die "bad signer cert" unless $ret;
 
@@ -84,7 +84,7 @@ sub handle_request {
         die "bad signature" unless $ret;
 
         my $cert = $x->signer_cert;
-        my $ca = Crypt::OpenSSL::VerifyX509->new($self->cacert);
+        my $ca = Crypt::OpenSSL::Verify->new($self->cacert, { strict_certs => 0, });
         $ret = $ca->verify($cert);
         die "bad certificate in request: ".$cert->subject unless $ret;
 
@@ -153,7 +153,7 @@ Net::SAML2::Binding::SOAP
 
 =head1 VERSION
 
-version 0.27
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -235,7 +235,7 @@ Original Author: Chris Andrews  <chrisa@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Chris Andrews and Others; in detail:
+This software is copyright (c) 2021 by Chris Andrews and Others; in detail:
 
   Copyright 2010-2011  Chris Andrews
             2012       Peter Marschall
